fnss.topologies.topology.DirectedTopology.number_of_nodes — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.2 documentation »

# fnss.topologies.topology.DirectedTopology.number_of_nodes

`DirectedTopology.` `number_of_nodes`()

  Return the number of nodes in the graph.

  Returns : | nnodes : int The number of nodes in the graph.

  See also

  `order`, `__len__`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2])
      >>> len(G)
      3

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.2 documentation »